DurationUnit

Enum DurationUnit 

pub enum DurationUnit {
    Nanoseconds,
    Microseconds,
    Milliseconds,
    Seconds,
    Minutes,
    Hours,
    Days,
}
Unit used when converting Duration values to and from scalar values.

Variants



Nanoseconds

Nanoseconds.



Microseconds

Microseconds.



Milliseconds

Milliseconds.



Seconds

Seconds.



Minutes

Minutes.



Hours

Hours.



Days

Days.

Implementations

Source

impl DurationUnit

pub const fn suffix(self) -> &'static str

Returns the canonical suffix for this duration unit.

Returns

The ASCII suffix used when formatting this unit.

pub fn from_suffix(suffix: &str) -> Option<Self>

Parses a duration unit suffix.

Parameters
  • suffix - Candidate unit suffix.
Returns

Returns the matched unit, or None when the suffix is unsupported.

pub fn duration_from_u64(self, value: u64) -> Result<Duration, String>

Converts an integer value in this unit to a Duration.

Parameters
  • value - Non-negative integer value expressed in this unit.
Returns

The corresponding Duration.

Errors

Returns an error message when converting the value to seconds would overflow the range supported by Duration.

pub fn rounded_units(self, duration: Duration) -> u128

Converts a Duration to this unit using half-up rounding.

Parameters
  • duration - Duration to format as an integer unit count.
Returns

The rounded number of units represented by the duration.