DataConversionOptions

Struct DataConversionOptions 

pub struct DataConversionOptions {
    pub string: StringConversionOptions,
    pub boolean: BooleanConversionOptions,
    pub collection: CollectionConversionOptions,
    pub duration: DurationConversionOptions,
}
Options that control common data conversion behavior.

Fields

string: StringConversionOptions

String source conversion behavior.

boolean: BooleanConversionOptions

Boolean string literal conversion behavior.

collection: CollectionConversionOptions

Scalar string collection conversion behavior.

duration: DurationConversionOptions

Duration conversion behavior.

Implementations

Source

impl DataConversionOptions

pub fn env_friendly() -> Self

Creates options suitable for environment variable style values.

Returns

Options that trim strings, treat blank scalar strings as missing, accept common boolean aliases, and split scalar strings on commas while skipping empty collection items.

pub fn with_blank_string_policy(self, policy: BlankStringPolicy) -> Self

Returns a copy with a different blank string policy.

Parameters
  • policy - New blank string policy.
Returns

Updated options.

pub fn with_empty_item_policy(self, policy: EmptyItemPolicy) -> Self

Returns a copy with a different empty collection item policy.

Parameters
  • policy - New empty item policy.
Returns

Updated options.

pub fn with_string_options(self, string: StringConversionOptions) -> Self

Returns a copy with different string conversion options.

Parameters
  • string - New string conversion options.
Returns

Updated options.

pub fn with_boolean_options(self, boolean: BooleanConversionOptions) -> Self

Returns a copy with different boolean conversion options.

Parameters
  • boolean - New boolean conversion options.
Returns

Updated options.

pub fn with_collection_options( self, collection: CollectionConversionOptions, ) -> Self

Returns a copy with different collection conversion options.

Parameters
  • collection - New collection conversion options.
Returns

Updated options.

pub fn with_duration_options(self, duration: DurationConversionOptions) -> Self

Returns a copy with different duration conversion options.

Parameters
  • duration - New duration conversion options.
Returns

Updated options.