pub enum DataConversionError {
NoValue,
ConversionFailed {
from: DataType,
to: DataType,
},
ConversionError(String),
JsonSerializationError(String),
JsonDeserializationError(String),
}Expand description
Error type returned by reusable data conversions.
Variants
NoValue
No concrete source value is available.
ConversionFailed
The source value type cannot be converted to the requested target type.
ConversionError(String)
Conversion failed because the source value content is invalid or out of range for the target type.
JsonSerializationError(String)
JSON serialization failed while converting a value to JSON text or a JSON value.
JsonDeserializationError(String)
JSON deserialization failed while parsing JSON text.